@@ -1,10 +1,7 @@
 package TestApp;
-our $VERSION = '0.05';
-
-
+our $VERSION = '0.06';
 
 use Moose;
-use MooseX::AttributeHelpers;
 use MooseX::Types::Moose qw/ArrayRef/;
 use namespace::autoclean;
 
@@ -12,14 +9,14 @@ extends 'Catalyst';
 with 'CatalystX::LeakChecker';
 
 has leaks => (
-    metaclass => 'Collection::Array',
-    is        => 'ro',
-    isa       => ArrayRef,
-    default   => sub { [] },
-    provides  => {
-        push  => 'add_leaks',
-        count => 'count_leaks',
-        first => 'first_leak',
+    traits  => [qw(Array)],
+    is      => 'ro',
+    isa     => ArrayRef,
+    default => sub { [] },
+    handles => {
+        add_leaks   => 'push',
+        count_leaks => 'count',
+        first_leak  => ['first', sub { 1 }],
     },
 );
 
